2025-12-30 Version: 2.4.0
- Support API CreateBizMetric.
- Support API DeleteBizMetric.
- Support API GetBizMetricByName.
- Support API GetCheckConnectivityJobs.
- Support API UpdateBizMetric.


2025-12-18 Version: 2.3.0
- Support API SyncDepartment.
- Support API SyncDepartmentUser.


2025-11-04 Version: 2.2.0
- Support API AddRegisterLineage.
- Support API CreatePipeline.
- Support API CreatePipelineByAsync.
- Support API DeleteRegisterLineage.
- Support API GetPipelineAsyncResult.
- Support API GetPipelineById.
- Support API OfflinePipeline.
- Support API OfflinePipelineByAsync.
- Support API UpdatePipeline.
- Support API UpdatePipelineByAsync.
- Update API GrantDataServiceApi: add request parameters GrantCommand.ApplyDev.
- Update API GrantDataServiceApi: add request parameters GrantCommand.ApplyProd.


2025-09-12 Version: 2.1.1
- Generated python 2023-06-30 for dataphin-public.

2025-08-29 Version: 2.1.0
- Support API GetTransferInfo.
- Support API RetryTransferOwnership.
- Support API TransferOwnershipForAllObject.


2025-08-18 Version: 2.0.1
- Update API CreateStreamBatchJobMapping: add response parameters Body.Data.JobId.


2025-07-31 Version: 2.0.0
- Support API AddDataServiceProjectMember.
- Support API AddProjectMember.
- Support API ApplyDataServiceApi.
- Support API ApplyDataServiceApp.
- Support API CheckComputeSourceConnectivity.
- Support API CheckComputeSourceConnectivityById.
- Support API CheckProjectHasDependency.
- Support API CreateComputeSource.
- Support API CreateResource.
- Support API CreateUdf.
- Support API DeleteComputeSource.
- Support API DeleteResource.
- Support API DeleteUdf.
- Support API GetComputeSource.
- Support API GetDataServiceApiCallSummary.
- Support API GetDataServiceApiCallTrend.
- Support API GetDataServiceApiDocument.
- Support API GetDataServiceApiErrorImpact.
- Support API GetDataServiceApiGroups.
- Support API GetDataServiceAppAuthorizedUsers.
- Support API GetDataServiceAppGroups.
- Support API GetDataServiceAppsByGroupId.
- Support API GetDataServiceAuthorizedAppsByGroupId.
- Support API GetDataServiceAuthorizedProjects.
- Support API GetDataServiceMyProjects.
- Support API GetDataServiceProjectAddableUsers.
- Support API GetDataSourceDependencies.
- Support API GetFileStorageCredential.
- Support API GetProject.
- Support API GetProjectByName.
- Support API GetProjectWhiteLists.
- Support API GetResource.
- Support API GetResourceByVersion.
- Support API GetStreamJobs.
- Support API GetUdf.
- Support API GetUdfByVersion.
- Support API GrantDataServiceApi.
- Support API ListComputeSources.
- Support API ListDataServiceApiCallStatistics.
- Support API ListDataServiceApiCalls.
- Support API ListDataServiceApiImpacts.
- Support API ListDataServiceAuthorizedApps.
- Support API ListDataServiceMyApiPermissions.
- Support API ListDataServiceMyAppPermissions.
- Support API ListDataServicePublishedApis.
- Support API ListProjectMembers.
- Support API ListProjects.
- Support API PublishDataServiceApi.
- Support API RemoveProjectMember.
- Support API ReplaceProjectWhiteLists.
- Support API RevokeDataServiceApi.
- Support API UpdateComputeSource.
- Support API UpdateProjectMember.
- Support API UpdateResource.
- Support API UpdateTenantComputeEngine.
- Support API UpdateUdf.
- Delete API SyncDepartment.
- Delete API SyncDepartmentUser.
- Update API GetBatchTaskInfo: add response parameters Body.TaskInfo.DevelopOwnerId.
- Update API GetBatchTaskInfo: add response parameters Body.TaskInfo.DevelopOwnerName.
- Update API GetBatchTaskInfo: add response parameters Body.TaskInfo.OpsOwnerId.
- Update API GetBatchTaskInfo: add response parameters Body.TaskInfo.OpsOwnerName.
- Update API ListInstances: add request parameters ListQuery.FlowId.


2025-04-28 Version: 1.4.0
- Support API CreateDataServiceApi.
- Support API CreateRowPermission.
- Support API DeleteRowPermission.
- Support API GetAccountByRowPermissionId.
- Support API GetTableColumnLineageByTaskId.
- Support API GetTableLineageByTaskId.
- Support API ListRowPermission.
- Support API ListRowPermissionByUserId.
- Support API SyncDepartment.
- Support API SyncDepartmentUser.
- Support API UpdateRowPermission.


2025-04-17 Version: 1.3.0
- Support API ListApiByApp.


2025-04-16 Version: 1.2.1
- Generated python 2023-06-30 for dataphin-public.

2025-03-07 Version: 1.2.0
- Support API GetSparkLocalClientInfo.
- Support API ListAuthorizedDataServiceApiDetails.
- Update API OperateInstance: update param OperateCommand.


2024-12-30 Version: 1.1.0
- Support API CreateBatchTask.
- Support API CreateBizEntity.
- Support API CreateBizUnit.
- Support API CreateDataDomain.
- Support API CreatePipelineNode.
- Support API CreateStreamBatchJobMapping.
- Support API DeleteBatchTask.
- Support API DeleteBizEntity.
- Support API DeleteBizUnit.
- Support API DeleteDataDomain.
- Support API ExecuteAdHocTask.
- Support API GetAdHocTaskLog.
- Support API GetAdHocTaskResult.
- Support API GetAlertEvent.
- Support API GetBatchTaskInfo.
- Support API GetBatchTaskInfoByVersion.
- Support API GetBatchTaskUdfLineages.
- Support API GetBatchTaskVersions.
- Support API GetBizEntityInfo.
- Support API GetBizEntityInfoByVersion.
- Support API GetBizUnitInfo.
- Support API GetClusterQueueInfoByEnv.
- Support API GetDataDomainInfo.
- Support API GetDirectoryTree.
- Support API GetLatestSubmitDetail.
- Support API GetQueueEngineVersionByEnv.
- Support API ListAlertEvents.
- Support API ListAlertNotifications.
- Support API ListBizEntities.
- Support API ListBizUnits.
- Support API ListDataDomains.
- Support API ListPublishRecords.
- Support API ListSubmitRecords.
- Support API OfflineBatchTask.
- Support API OfflineBizEntity.
- Support API OnlineBizEntity.
- Support API ParseBatchTaskDependency.
- Support API PublishObjectList.
- Support API StopAdHocTask.
- Support API SubmitBatchTask.
- Support API UpdateBatchTask.
- Support API UpdateBatchTaskUdfLineages.
- Support API UpdateBizEntity.
- Support API UpdateBizUnit.
- Support API UpdateDataDomain.


2024-10-11 Version: 1.0.0
- Generated python 2023-06-30 for dataphin-public.

